from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Quantity(Intangible):
    """Quantities such as distance, time, mass, weight, etc. Particular instances of say Mass are entities like
     '3 kg' or '4 milligrams'.

    See: https://schema.org/Quantity
    Model depth: 3
    """

    type_: str = Field(default="Quantity", alias="@type", const=True)
