from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.USNonprofitType import USNonprofitType


class Nonprofit501c24(USNonprofitType):
    """Nonprofit501c24: Non-profit type referring to Section 4049 ERISA Trusts.

    See: https://schema.org/Nonprofit501c24
    Model depth: 6
    """

    type_: str = Field(default="Nonprofit501c24", alias="@type", const=True)
