from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class Infectious(MedicalSpecialty):
    """Something in medical science that pertains to infectious diseases, i.e. caused by bacterial, viral, fungal
     or parasitic infections.

    See: https://schema.org/Infectious
    Model depth: 6
    """

    type_: str = Field(default="Infectious", alias="@type", const=True)
