from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Service import Service


class TaxiService(Service):
    """A service for a vehicle for hire with a driver for local travel. Fares are usually calculated based on distance
     traveled.

    See: https://schema.org/TaxiService
    Model depth: 4
    """

    type_: str = Field(default="TaxiService", alias="@type", const=True)
