from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.USNonprofitType import USNonprofitType


class Nonprofit501c8(USNonprofitType):
    """Nonprofit501c8: Non-profit type referring to Fraternal Beneficiary Societies and Associations.

    See: https://schema.org/Nonprofit501c8
    Model depth: 6
    """

    type_: str = Field(default="Nonprofit501c8", alias="@type", const=True)
