from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure


class BrainStructure(AnatomicalStructure):
    """Any anatomical structure which pertains to the soft nervous tissue functioning as the coordinating center
     of sensation and intellectual and nervous activity.

    See: https://schema.org/BrainStructure
    Model depth: 4
    """

    type_: str = Field(default="BrainStructure", alias="@type", const=True)
