from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class Rheumatologic(MedicalSpecialty):
    """A specific branch of medical science that deals with the study and treatment of rheumatic, autoimmune or joint
     diseases.

    See: https://schema.org/Rheumatologic
    Model depth: 6
    """

    type_: str = Field(default="Rheumatologic", alias="@type", const=True)
