from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class ComputerLanguage(Intangible):
    """This type covers computer programming languages such as Scheme and Lisp, as well as other language-like computer
     representations. Natural languages are best represented with the [[Language]] type.

    See: https://schema.org/ComputerLanguage
    Model depth: 3
    """

    type_: str = Field(default="ComputerLanguage", alias="@type", const=True)
