from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.UserInteraction import UserInteraction


class UserPlusOnes(UserInteraction):
    """UserInteraction and its subtypes is an old way of talking about users interacting with pages. It is generally
     better to use [[Action]]-based vocabulary, alongside types such as [[Comment]].

    See: https://schema.org/UserPlusOnes
    Model depth: 4
    """

    type_: str = Field(default="UserPlusOnes", alias="@type", const=True)
