from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BodyMeasurementTypeEnumeration import (
    BodyMeasurementTypeEnumeration,
)


class BodyMeasurementFoot(BodyMeasurementTypeEnumeration):
    """Foot length (measured between end of the most prominent toe and the most prominent part of the heel). Used,
     for example, to measure socks.

    See: https://schema.org/BodyMeasurementFoot
    Model depth: 6
    """

    type_: str = Field(default="BodyMeasurementFoot", alias="@type", const=True)
